CompressLevel enum
Values
- level1 → const CompressLevel
- level2 → const CompressLevel
- level3 → const CompressLevel
- level4 → const CompressLevel
- level5 → const CompressLevel
- level6 → const CompressLevel
- level7 → const CompressLevel
- level8 → const CompressLevel
- level9 → const CompressLevel
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
CompressLevel> - A constant List of the values in this enum, in order of their declaration.