XLog class abstract base

Constructors

XLog()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

close() Future<void>
debug(String tag, String message) Future<void>
decode(Uint8List buffer, {String privKey = ''}) Future<Uint8List>
error(String tag, String message) Future<void>
fatal(String tag, String message) Future<void>
flush(bool isSync) Future<void>
info(String tag, String message) Future<void>
onRecord(LogRecord record) → void
open({AppenderMode mode = AppenderMode.async, XLogLevel level = kDebugMode ? XLogLevel.debug : XLogLevel.info, required String logsDir, required String cacheDir, int cacheDays = 0, String namePrefix = '', CompressMode compressMode = CompressMode.zlib, CompressLevel compressLevel = CompressLevel.level6, String pubKey = '', bool useConsole = kDebugMode, int maxFileSize = 0, int maxAliveDuration = 10 * 24 * 60 * 60}) Future<void>
verbose(String tag, String message) Future<void>
warning(String tag, String message) Future<void>